<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

use Invertus\SwedBank\Service\OrderHandler;
use SwedbankPaymentPortal\SharedEntity\Type\TransactionResult;
use SwedbankPaymentPortal\SwedbankPaymentPortal;

class SwedBankHpsConfirmModuleFrontController extends ModuleFrontController
{
    /**
     * @var SwedBank
     */
    public $module;

    public function checkAccess()
    {
        $idOrder = Tools::getValue('id_order');
        $order = new Order($idOrder);

        $customerAccess = $this->context->customer->id == $order->id_customer;

        if (!Validate::isLoadedObject($order) ||
            !$customerAccess ||
            !$this->module->active ||
            !$this->module->isConfigured() ||
            $order->module != $this->module->name
        ) {
            Tools::redirect($this->context->link->getPageLink('404'));
        }

        return true;
    }

    public function postProcess()
    {
        $idLang = $this->context->language->id;
        $idOrder = Tools::getValue('id_order');
        $order = new Order($idOrder);

        /** @var SwedbankPaymentPortal $paymentPortal */
        $paymentPortal = $this->module->get(SwedbankPaymentPortal::class);

        /** @var OrderHandler $orderService */
        $orderService = $this->module->get(OrderHandler::class);

        $idUnique = SwedbankOrderPayment::retrieveUniqueId($idOrder, $this->context->shop->id);
        $merchantReference = $orderService->getMerchantReference($order, $idUnique);

        try {
            $result = $paymentPortal->getPaymentCardHostedPagesGateway()
                ->handlePendingTransaction($merchantReference);

            $redirectUrl = $orderService->getOrderConfirmationUrl($order, $idLang);

            if (TransactionResult::failure() === $result) {
                $this->errors = $this->module
                    ->l('Operation failed. Please choose another payment method or try again.', 'hpsconfirm');
            } elseif (TransactionResult::unfinished() === $result) {
                $customer = new Customer($order->id_customer);
                $redirectUrl = $orderService->getOrderDetailLink($customer, $order, $idLang);
            }

            if (!empty($this->errors)) {
                $this->redirectWithNotifications();
            }

            Tools::redirect($redirectUrl);
        } catch (Exception $e) {
            $debug = (bool) Configuration::get('SB_DEBUG_MODE_'.Tools::strtoupper($this->module->getEnvironment()));

            if ($debug) {
                throw $e;
            }

            $this->errors =
                $this->module->l('Operation failed. Please choose another payment method or try again.', 'hpsconfirm');

            $redirectUrl = $orderService->getOrderConfirmationUrl($order, $idLang);
            $this->redirectWithNotifications($redirectUrl);
        }
    }
}
