<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

namespace Invertus\SwedBank\Config;

class Config
{
    /**
     * live and test controller configuration variables
     */
    const TEST_ENVIRONMENT = 'SB_TEST_ENVIRONMENT';
    const LIVE_ENVIRONMENT = 'SB_LIVE_ENVIRONMENT';
    const TERMS_AND_CONDITIONS = 'SB_TERMS_AND_CONDITIONS';

    const TERMS_AND_CONDITIONS_TEST = 'SB_TERMS_AND_CONDITIONS_TEST';
    const TERMS_AND_CONDITIONS_LIVE = 'SB_TERMS_AND_CONDITIONS_LIVE';

    /**
     * variables for configuration controller
     */
    const BANK_LT = 'SB_BANK_LT'; //todo: do we need to use not hard coded country ids and to check if they are enabled?
    const BANK_LV = 'SB_BANK_LV';
    const BANK_EE = 'SB_BANK_EE';
    /**
     * test and live controller variables
     */
    const CLIENT_ID = 'SB_CLIENT_ID';
    const CLIENT_PASSWORD = 'SB_CLIENT_PASSWORD';

    const CLIENT_ID_TEST = 'SB_CLIENT_ID_TEST';
    const CLIENT_PASSWORD_TEST = 'SB_CLIENT_PASSWORD_TEST';

    const CLIENT_ID_LIVE = 'SB_CLIENT_ID_LIVE';
    const CLIENT_PASSWORD_LIVE = 'SB_CLIENT_PASSWORD_LIVE';

    const ORDER_STATUS_SUCCESS = 'SB_ORDER_STATUS_SUCCESS';
    const ORDER_STATUS_FAILED = 'SB_ORDER_STATUS_FAILED';
    const ORDER_STATUS_REQINV = 'SB_ORDER_STATUS_REQINV';

    const ORDER_STATUS_SUCCESS_TEST = 'SB_ORDER_STATUS_SUCCESS_TEST';
    const ORDER_STATUS_AWAITING_TEST = 'SB_ORDER_STATUS_AWAITING_TEST';
    const ORDER_STATUS_REQUIRES_INVESTIGATION_TEST = 'SB_ORDER_STATUS_REQINV_TEST';
    const DEBUG_MODE_TEST = 'SB_DEBUG_MODE_TEST';

    const ORDER_STATUS_SUCCESS_LIVE = 'SB_ORDER_STATUS_SUCCESS_LIVE';
    const ORDER_STATUS_FAILED_LIVE = 'SB_ORDER_STATUS_FAILED_LIVE';
    const ORDER_STATUS_AWAITING_LIVE = 'SB_ORDER_STATUS_AWAITING_LIVE';
    const ORDER_STATUS_REQUIRES_INVESTIGATION_LIVE = 'SB_ORDER_STATUS_REQINV_LIVE';
    const DEBUG_MODE_LIVE = 'SB_DEBUG_MODE_LIVE';

    const PAYMENT_METHODS_TEST = 'SB_PAYMENT_METHODS_TEST';
    const PAYMENT_METHODS_LIVE = 'SB_PAYMENT_METHODS_LIVE';

    const LANGUAGE_LT = 'LT';
    const LANGUAGE_EN = 'EN';
    const LANGUAGE_RU = 'RU';
    const LANGUAGE_LV = 'LV';
    const LANGUAGE_EE = 'ET';

    const LANGUAGE_TYPE_BANKLINK = 'banklink';
    const LANGUAGE_TYPE_CARD = 'card';

    /**
     * payment method constants
     */
    const PAYMENT_METHOD_CARD = 1;
    const PAYMENT_METHOD_SWEDBANK = 2;
    const PAYMENT_METHOD_SEB = 3;
    const PAYMENT_METHOD_DNB = 4;
    const PAYMENT_METHOD_NORDEA = 5;
    const PAYMENT_METHOD_DANSKE = 6;
    const PAYMENT_METHOD_PAYPAL = 7;
    const PAYMENT_METHOD_CITADELE = 8;
    /**
     * id which sets to url parameter in back-office and indicates message which is retrieved after page refresh.
     */
    const CONFIRMATION_MESSAGE_ID = 6;

    public static function getFieldsFormLanguages($country = null)
    {
        $langs = [
            [
                'id' => Config::LANGUAGE_LT,
                'name' => Config::LANGUAGE_LT,
                'tags' => ['LT'],
            ],
            [
                'id' => Config::LANGUAGE_LV,
                'name' => Config::LANGUAGE_LV,
                'tags' => ['LV'],
            ],
            [
                'id' => Config::LANGUAGE_EE,
                'name' => Config::LANGUAGE_EE,
                'tags' => ['EE'],
            ],
            [
                'id' => Config::LANGUAGE_EN,
                'name' => Config::LANGUAGE_EN,
                'tags' => ['LT', 'LV', 'EE'],
            ],
            [
                'id' => Config::LANGUAGE_RU,
                'name' => Config::LANGUAGE_RU,
                'tags' => ['LV', 'EE'],
            ],
        ];

        if ($country) {
            $langs = array_filter($langs, function ($lang) use ($country) {
                return in_array($country, $lang['tags']);
            });
        }

        return $langs;
    }

    public static function getPaymentMethodIds()
    {
        return [
            self::PAYMENT_METHOD_CITADELE,
            self::PAYMENT_METHOD_PAYPAL,
            self::PAYMENT_METHOD_DANSKE,
            self::PAYMENT_METHOD_NORDEA,
            self::PAYMENT_METHOD_DNB,
            self::PAYMENT_METHOD_SEB,
            self::PAYMENT_METHOD_SWEDBANK,
            self::PAYMENT_METHOD_CARD
        ];
    }

    public static function getBankLinkPaymentMethodIds()
    {
        return [
            self::PAYMENT_METHOD_CITADELE,
            self::PAYMENT_METHOD_DANSKE,
            self::PAYMENT_METHOD_NORDEA,
            self::PAYMENT_METHOD_DNB,
            self::PAYMENT_METHOD_SEB,
            self::PAYMENT_METHOD_SWEDBANK,
        ];
    }

    public static function getDefaultConfiguration()
    {
        return [
            self::TEST_ENVIRONMENT => 0,
            self::LIVE_ENVIRONMENT => 0,
            self::TERMS_AND_CONDITIONS => 0,
            self::BANK_LT => 0,
            self::BANK_LV => 0,
            self::BANK_EE => 0,
            self::ORDER_STATUS_SUCCESS => 0,
            self::ORDER_STATUS_FAILED => 0,
            self::ORDER_STATUS_REQINV => 0,
        ];
    }
}
