<?php
/**
 * NOTICE OF LICENSE
 *
 * @author    INVERTUS, UAB www.invertus.eu <support@invertus.eu>
 * @copyright Copyright (c) permanent, INVERTUS, UAB
 * @license   Addons PrestaShop license limitation
 * @see       /LICENSE
 *
 * International Registered Trademark & Property of INVERTUS, UAB
 */

namespace Invertus\SwedBank\Factory;

use Exception;
use Invertus\SwedBank\Adapter\Configuration;
use Invertus\SwedBank\Config\Config;
use SwedBank;
use SwedbankPaymentPortal\Logger\LoggerInterface;
use SwedbankPaymentPortal\Options\CommunicationOptions;
use SwedbankPaymentPortal\Options\ServiceOptions;
use SwedbankPaymentPortal\SharedEntity\Authentication;
use SwedbankPaymentPortal\SwedbankPaymentPortal;

class PaymentPortalFactory
{
    /**
     * @var Configuration
     */
    private $configuration;

    /**
     * @var LoggerInterface
     */
    private $logger;
    /**
     * @var SwedBank
     */
    private $module;

    /**
     * @var Authentication
     */
    private $authentication;

    public function __construct(
        Configuration $configuration,
        LoggerInterface $logger,
        SwedBank $module,
        Authentication $authentication
    ) {
        $this->configuration = $configuration;
        $this->logger = $logger;
        $this->module = $module;
        $this->authentication = $authentication;
    }

    /**
     * @return SwedbankPaymentPortal
     *
     * @throws Exception
     */
    public function createNew()
    {
        $environment = \Tools::strtoupper($this->module->getEnvironment());

        $debugMode = (bool) $this->configuration->get('SB_DEBUG_MODE_'.$environment);
        $logger = $debugMode ? $this->logger : null;

        $liveMode = (bool) $this->configuration->get(Config::LIVE_ENVIRONMENT);
        $endpoint = $liveMode ?
            'https://mars.transaction.datacash.com/Transaction' :
            'https://accreditation.datacash.com/Transaction/acq_a';

        $communicationOptions = new CommunicationOptions($endpoint);

        $options = new ServiceOptions($communicationOptions, $this->authentication, $logger);
        $spp = new SwedbankPaymentPortal($options);

        return $spp;
    }
}
